cumulusci.tasks package
=======================

.. automodule:: cumulusci.tasks
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::

   cumulusci.tasks.apex
   cumulusci.tasks.bulkdata
   cumulusci.tasks.github
   cumulusci.tasks.metadata
   cumulusci.tasks.metadata_etl
   cumulusci.tasks.push
   cumulusci.tasks.release_notes
   cumulusci.tasks.robotframework
   cumulusci.tasks.salesforce

Submodules
----------

cumulusci.tasks.command module
------------------------------

.. automodule:: cumulusci.tasks.command
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.connectedapp module
-----------------------------------

.. automodule:: cumulusci.tasks.connectedapp
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.datadictionary module
-------------------------------------

.. automodule:: cumulusci.tasks.datadictionary
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.metadeploy module
---------------------------------

.. automodule:: cumulusci.tasks.metadeploy
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.metaxml module
------------------------------

.. automodule:: cumulusci.tasks.metaxml
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.sfdx module
---------------------------

.. automodule:: cumulusci.tasks.sfdx
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.util module
---------------------------

.. automodule:: cumulusci.tasks.util
   :members:
   :undoc-members:
   :show-inheritance:

